@@ -6,14 +6,15 @@ import shlex
 
 import requests
 
+from ncurl.utils import join
 from .curl_utils import CurlUtils
 
-server_url = 'https://ncurl-server.herokuapp.com/api'
-web_url = 'https://ncurl.github.io/ncurl-web/instants/'
+server_url = 'https://api.ncurl.sh/api'
+web_url = 'https://ncurl.sh/instants/'
 
 
 def do_curl():
-    command = ['curl', '-s'] + sys.argv[1:]
+    command = ['curl', '-sS'] + sys.argv[1:]
 
     process = subprocess.Popen(command,
                                stdout=subprocess.PIPE,
@@ -25,11 +26,15 @@ def do_curl():
     upload_contents = list(map(lambda content: dict(content=content.content, highlightName=content.lexer.name.lower()),
                                curl_utils.contents))
     result = requests.post(f'{server_url}/instants', json={
-        "commands": shlex.join(['curl'] + sys.argv[1:]),
+        "commands": join(['curl'] + sys.argv[1:]),
         "contents": upload_contents
     })
-    union_id = result.content.decode("utf-8")
-    print(f'\nView and share in: {web_url}?id=/{union_id}')
+    response_str = result.content.decode("utf-8")
+    if result.status_code == 200:
+        print(f'\nView and share in: {web_url}?id=/{response_str}')
+    else:
+        print(f'Failed upload to server: {response_str}')
+        sys.exit(1)
 
 
 def main():
