@@ -26,9 +26,12 @@ class OutputContent(object):
     def __str__(self) -> str:
         return f"content: {self.content}, lexer: {self.lexer}"
 
+    def __repr__(self) -> str:
+        return self.__str__()
+
 
 class CurlUtils(object):
-    contents: List[OutputContent] = []
+    contents: List[OutputContent] = None
     include: bool = False
     verbose: bool = False
 
@@ -36,6 +39,7 @@ class CurlUtils(object):
         self._output = output
         self._stderr = stderr
         self._command = command
+        self.contents = []
         self.command_line_args_parse()
         self.parse_output()
 
@@ -62,24 +66,34 @@ class CurlUtils(object):
                         tail_content = '\n'.join(lines[sub_index:])
                         self.contents.append(OutputContent(BashLexer(), tail_content))
                         break
+                return
+
+        self.contents.append(OutputContent(BashLexer(), self._stderr))
+        body_content = '\n'.join(self._output.splitlines())
+        self.contents.append(OutputContent(self.get_lexer(body_content), body_content))
+
+    def _include_parse_output(self):
+        if self._stderr.strip() != '':
+            self.contents.append(OutputContent(BashLexer(), self._stderr))
+        lines = self._output.splitlines()
+        for index, line in enumerate(lines):
+            if line.strip() == '':
+                header_content = '\n'.join(lines[:index])
+                self.contents.append(OutputContent(BashLexer(), header_content))
+                body_content = '\n'.join(lines[index + 1:])
+                self.contents.append(OutputContent(self.get_lexer(body_content), body_content))
                 break
 
-    def parse_output(self):
-        output = self._output
-        if self.include and not self.verbose:
-            lines = output.splitlines()
-            for index, line in enumerate(lines):
-                if line.strip() == '':
-                    header_content = '\n'.join(lines[:index])
-                    self.contents.append(OutputContent(BashLexer(), header_content))
-                    body_content = '\n'.join(lines[index + 1:])
-                    self.contents.append(OutputContent(self.get_lexer(body_content), body_content))
-                    break
 
+    def parse_output(self):
+        if self.include and not self.verbose:
+            self._include_parse_output()
         if self.verbose:
             self._verbose_parse_output()
-
         if not self.include and not self.verbose:
+            output = self._output
+            stderr = self._stderr
+            self.contents.append(OutputContent(BashLexer(), stderr))
             self.contents.append(OutputContent(self.get_lexer(output), output))
 
 
